/** @file certificates.c
 *  @brief Read cert and key from partitions
 */

#include "agg_appsupp.h"
#include "agg_iotsupp.h"

static const char* TAG = "CERT";

esp_err_t ca_load_certificate(char * cert)
{
    esp_err_t err;

    const esp_partition_t *cert_part = esp_partition_find_first(PARTN_SUBTYPE_CUSTOM_CERT, ESP_PARTITION_SUBTYPE_ANY, (const char *)"cert");

    if(cert_part == NULL)
    {
        ESP_LOGE(TAG,"CERT PARTITION COULD NOT BE FOUND");
        return ESP_FAIL;
    }

    err = esp_partition_read(cert_part,0,(void *)cert,cert_part->size);

    if (err)
    {
        ESP_LOGE(TAG,"esp_partition_read failed in load_certificate with %x",err);
        return ESP_FAIL;
    }

    return ESP_OK;
}

esp_err_t ca_load_key(char * key)
{
    esp_err_t err;

    const esp_partition_t *key_part = esp_partition_find_first(PARTN_SUBTYPE_CUSTOM_CERT, ESP_PARTITION_SUBTYPE_ANY, (const char *)"key");

    if(key_part == NULL)
    {
        ESP_LOGE(TAG,"KEY PARTITION COULD NOT BE FOUND");
        return ESP_FAIL;
    }

    err = esp_partition_read(key_part,0,(void *)key,CA_KEY_SIZE);

    if (err)
    {
        ESP_LOGE(TAG,"esp_partition_read failed in load_key with %x",err);
        return ESP_FAIL;
    }

    return ESP_OK;
}