/** @file mqtt.h
 *  @brief Application-specific MQTT cloud communication, hides default ESP mqtt component.
 *
 */

#ifndef _MQTT_H
#define _MQTT_H


#define MQTT_JSON_MAX_MSG_BYTE  (1536)  // Buffer allocation for complete JSON-formatted data msg

#define MQTT_MAX_FAIL              10  // Maximum number of consecutive 

// Auto provision
#define DPS_ID_SCOPE        "0ne0004975E"
#define CA_CERT_SIZE        8192
#define CA_KEY_SIZE         4096

typedef struct EVENT_INSTANCE_TAG
{
    IOTHUB_MESSAGE_HANDLE messageHandle;
} EVENT_INSTANCE;

typedef void (*resp_function) (void*);

typedef struct cloud_message_resp {
    char * key;
    resp_function response_function;
} cloud_message_resp_t;

typedef struct device_method_resp {
    char * function_name;
    resp_function response_function;
} device_method_resp_t;

extern IOTHUB_CLIENT_LL_HANDLE iotHubClientHandle;


// Begin C++ guard around prototypes
#ifdef __cplusplus
extern "C" {
#endif


void mqtt_deinit(void);
void mqtt_init(void);
int  mqtt_sendMessage(char *text);
void mqtt_do_work(void);

int deviceMethodCallback(const char* method_name, const unsigned char* payload, size_t size, unsigned char** response, size_t* response_size, void* userContextCallback);
void deviceTwinCallback(DEVICE_TWIN_UPDATE_STATE update_state, const unsigned char* payLoad, size_t size, void* userContextCallback);
void reportedStateCallback(int status_code, void* userContextCallback);

esp_err_t ca_load_certificate(char * cert);
esp_err_t ca_load_key(char * key);

IOTHUB_DEVICE_CLIENT_LL_HANDLE prov_dev_client();
IOTHUB_DEVICE_CLIENT_LL_HANDLE conn_dev_client();


// End C++ guard
#ifdef __cplusplus
}
#endif

#endif  // _MQTT_H