/** @file agg_appsupp.h
 *  @brief Aggregated list of C header files for low-level 
 *  supporting functionality.
 *
 *  To keep #include sections of most source files small, 
 *  many commonly-needed header files are listed here, 
 *  and this one file may be #included.
 *
 */

#ifndef _AGG_APPSUPP_H
#define _AGG_APPSUPP_H

// C libraries
#include <stdint.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <sys/unistd.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netdb.h>

// IDF libraries, including some FreeRTOS APIs
#include "esp_task.h"
#include "esp_err.h"
#include "esp_log.h"
#include "esp_spiffs.h"
#include "esp_partition.h"
#include "esp_event.h" // esp_event_loop.h is deprecated, please include esp_event.h instead
#include "esp_tls.h"
#include "esp_wifi.h"
#include "esp_sleep.h"

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "freertos/semphr.h"
#include "freertos/event_groups.h"
#include "driver/periph_ctrl.h"
#include "driver/gpio.h"
#include "driver/timer.h"
#include "soc/dport_reg.h"
#include "soc/timer_group_struct.h"
#include "nvs_flash.h"

#include "tcpip_adapter.h"
#include "lwip/api.h"
#include "lwip/inet.h"
#include "lwip/ip4_addr.h"
#include "lwip/dns.h"

// IDF menuconfig settings including custom values
// from sdkconfig.defaults
#include "sdkconfig.h"


#define PARTN_SUBTYPE_CUSTOM_BASE    0x40  // Start of range of custom ptn types
#define PARTN_SUBTYPE_CUSTOM_CERT    0x40  // Secure certificates

#define BUFF_SZ_EFUSE_MAC      ( 8)  // Storage to hold MAC raw bytes 
#define BUFF_SZ_EFUSE_MAC_STR  (16)  // Storage to hold string representation of MAC

typedef enum state
{
    DEVICE_STATE_SOFT_AP = 0,
    DEVICE_STATE_CONNECTING_TO_WIFI,
    DEVICE_STATE_SENSING,
    DEVICE_STATE_STREAMING,
    DEVICE_STATE_SENDING,
    DEVICE_STATE_BATTERY
} state_t;

typedef struct craftalert_conf {
    char * mac;
} craftalert_conf_t;

extern craftalert_conf_t *device_config;

// Storage to hold MAC value from esp_efuse_mac_get_default().
// Persistent global copies of raw bytes as well
// as string representation.
// Give buffers 32-bit alignment.
extern uint8_t efuse_mac[BUFF_SZ_EFUSE_MAC];   // Persistent global to hold MAC raw bytes
extern char efuse_mac_str[BUFF_SZ_EFUSE_MAC_STR];

void fatal_error(const char * TAG, char * message) ;

#endif  // _AGG_APPSUPP_H
